@@ -2,7 +2,7 @@
 import asyncio
 import logging
 from enum import Enum
-from typing import TYPE_CHECKING, Any, Coroutine, Dict, List, Type, Set, Union
+from typing import Any, Callable, Coroutine, Dict, List, Type, Set, Union
 
 from simplipy.entity import Entity, EntityTypes
 from simplipy.errors import InvalidCredentialsError, PinError, SimplipyError
@@ -11,9 +11,6 @@ from simplipy.sensor.v2 import SensorV2
 from simplipy.sensor.v3 import SensorV3
 from simplipy.util.string import convert_to_underscore
 
-if TYPE_CHECKING:
-    from simplipy.api import API
-
 _LOGGER: logging.Logger = logging.getLogger(__name__)
 
 VERSION_V2 = 2
@@ -88,7 +85,7 @@ def get_entity_class(
 
 
 class SystemStates(Enum):
-    """Define states that the system can be in."""
+    """States that the system can be in."""
 
     alarm_count = 1
     away = 2
@@ -103,12 +100,29 @@ class SystemStates(Enum):
 
 
 class System:
-    """Define a system."""
+    """Define a system.
 
-    def __init__(self, api: "API", location_info: dict) -> None:
+    Note that this class shouldn't be instantiated directly; it will be instantiated as
+    appropriate via :meth:`simplipy.API.get_systems`.
+
+    :param request: A method to make authenticated API requests.
+    :type request: ``Callable[..., Coroutine]``
+    :param get_subscription_data: A method to get the latest subscription data
+    :type get_subscription_data: ``Callable[..., Coroutine]``
+    :param location_info: A raw data dict representing the system's state and properties.
+    :type location_info: ``dict``
+    """
+
+    def __init__(
+        self,
+        request: Callable[..., Coroutine],
+        get_subscription_data: Callable[..., Coroutine],
+        location_info: dict,
+    ) -> None:
         """Initialize."""
+        self._get_subscription_data: Callable[..., Coroutine] = get_subscription_data
         self._location_info: dict = location_info
-        self.api: "API" = api
+        self._request: Callable[..., Coroutine] = request
         self.locks: Dict[str, Lock] = {}
         self.sensors: Dict[str, Union[SensorV2, SensorV3]] = {}
 
@@ -117,43 +131,67 @@ class System:
         )
 
     @property
-    def address(self) -> bool:
-        """Return the street address of the system."""
+    def address(self) -> str:
+        """Return the street address of the system.
+
+        :rtype: ``str``
+        """
         return self._location_info["street1"]
 
     @property
     def alarm_going_off(self) -> bool:
-        """Return whether the alarm is going off."""
+        """Return whether the alarm is going off.
+
+        :rtype: ``bool``
+        """
         return self._location_info["system"]["isAlarming"]
 
     @property
     def connection_type(self) -> str:
-        """Return the system's connection type (cell or WiFi)."""
+        """Return the system's connection type (cell or WiFi).
+
+        :rtype: ``str``
+        """
         return self._location_info["system"]["connType"]
 
     @property
     def serial(self) -> str:
-        """Return the system's serial number."""
+        """Return the system's serial number.
+
+        :rtype: ``str``
+        """
         return self._location_info["system"]["serial"]
 
     @property
     def state(self) -> SystemStates:
-        """Return the current state of the system."""
+        """Return the current state of the system.
+
+        :rtype: :meth:`simplipy.system.SystemStates`
+        """
         return self._state
 
     @property
     def system_id(self) -> int:
-        """Return the SimpliSafe identifier for this system."""
+        """Return the SimpliSafe identifier for this system.
+
+        :rtype: ``int``
+        """
         return self._location_info["sid"]
 
     @property
     def temperature(self) -> int:
-        """Return the overall temperature measured by the system."""
+        """Return the overall temperature measured by the system.
+
+        :rtype: ``int``
+        """
         return self._location_info["system"]["temperature"]
 
     @property
     def version(self) -> int:
-        """Return the system version."""
+        """Return the system version.
+
+        :rtype: ``int``
+        """
         return self._location_info["system"]["version"]
 
     @staticmethod
@@ -165,19 +203,7 @@ class System:
             _LOGGER.error("Unknown system state: %s", value)
             return SystemStates.unknown
 
-    async def _get_entities_payload(self, cached: bool = False) -> dict:
-        """Return the current sensor payload."""
-        raise NotImplementedError()
-
-    async def _send_updated_pins(self, pins: dict) -> None:
-        """Post new PINs."""
-        raise NotImplementedError()
-
-    async def _set_state(self, value: SystemStates) -> None:
-        """Raise if calling this undefined based method."""
-        raise NotImplementedError()
-
-    async def _update_entities(self, cached: bool = True) -> None:
+    async def _get_entities(self, cached: bool = True) -> None:
         """Update sensors to the latest values."""
         entities: dict = await self._get_entities_payload(cached)
 
@@ -205,12 +231,24 @@ class System:
             else:
                 klass = get_entity_class(entity_type, version=self.version)
                 prop[entity_data["serial"]] = klass(  # type: ignore
-                    self.api, self.system_id, entity_type, entity_data
+                    self._request,
+                    self._get_entities,
+                    self.system_id,
+                    entity_type,
+                    entity_data,
                 )
 
-    async def _update_location_info(self) -> None:
+    async def _get_entities_payload(self, cached: bool = False) -> dict:
+        """Return the current sensor payload."""
+        raise NotImplementedError()
+
+    async def _get_settings(self, cached: bool = True) -> None:
+        """Get all system settings."""
+        pass
+
+    async def _get_system_info(self) -> None:
         """Update information on the system."""
-        subscription_resp: dict = await self.api.get_subscription_data()
+        subscription_resp: dict = await self._get_subscription_data()
         location_info: dict = next(
             (
                 system["location"]
@@ -224,21 +262,34 @@ class System:
             location_info["system"]["alarmState"]
         )
 
-    async def _update_settings(self, cached: bool = True) -> None:
-        """Update system settings."""
-        pass
+    async def _set_updated_pins(self, pins: dict) -> None:
+        """Post new PINs."""
+        raise NotImplementedError()
+
+    async def _set_state(self, value: SystemStates) -> None:
+        """Raise if calling this undefined based method."""
+        raise NotImplementedError()
 
     async def get_events(
         self, from_timestamp: int = None, num_events: int = None
     ) -> list:
-        """Get events with optional start time and number of events."""
+        """Get events recorded by the base station.
+
+        If no parameters are provided, this will return the most recent 50 events.
+
+        :param from_timestamp: The starting timestamp (if desired)
+        :type from_timestamp: ``int``
+        :param num_events: The number of events to return.
+        :type num_events: ``int``
+        :rtype: ``list``
+        """
         params: Dict[str, Any] = {}
         if from_timestamp:
             params["fromTimestamp"] = from_timestamp
         if num_events:
             params["numEvents"] = num_events
 
-        events_resp: dict = await self.api.request(
+        events_resp: dict = await self._request(
             "get", f"subscriptions/{self.system_id}/events", params=params
         )
 
@@ -247,20 +298,35 @@ class System:
         return events_resp["events"]
 
     async def get_latest_event(self) -> dict:
-        """Get the most recent system event."""
+        """Get the most recent system event.
+
+        :rtype: ``dict``
+        """
         events: list = await self.get_events(num_events=1)
         return events[0]
 
-    async def get_pins(self, cached: bool = True) -> dict:
-        """Return all of the set PINs, including master and duress."""
+    async def get_pins(self, cached: bool = True) -> Dict[str, str]:
+        """Return all of the set PINs, including master and duress.
+
+        The ``cached`` parameter determines whether the SimpliSafe Cloud uses the last
+        known values retrieved from the base station (``True``) or retrieves new data.
+
+        :param cached: Whether to used cached data.
+        :type cached: ``bool``
+        :rtype: ``Dict[str, str]``
+        """
         raise NotImplementedError()
 
     async def remove_pin(self, pin_or_label: str) -> None:
-        """Remove a PIN by its value or label."""
+        """Remove a PIN by its value or label.
+
+        :param pin_or_label: The PIN value or label to remove
+        :type pin_or_label: ``str``
+        """
         # Because SimpliSafe's API works by sending the entire payload of PINs, we
         # can't reasonably check a local cache for up-to-date PIN data; so, we fetch the
         # latest each time:
-        latest_pins: Dict[str, int] = await self.get_pins(cached=False)
+        latest_pins: Dict[str, str] = await self.get_pins(cached=False)
 
         if pin_or_label in RESERVED_PIN_LABELS:
             raise PinError(f"Refusing to delete reserved PIN: {pin_or_label}")
@@ -274,7 +340,7 @@ class System:
 
         del latest_pins[label]
 
-        await self._send_updated_pins(latest_pins)
+        await self._set_updated_pins(latest_pins)
 
     async def set_away(self) -> None:
         """Set the system in "Away" mode."""
@@ -289,7 +355,13 @@ class System:
         await self._set_state(SystemStates.off)
 
     async def set_pin(self, label: str, pin: str) -> None:
-        """Set a PIN."""
+        """Set a PIN.
+
+        :param label: The label to use for the PIN (shown in the SimpliSafe app)
+        :type label: str
+        :param pin: The pin value
+        :type pin: str
+        """
         if len(pin) != MAX_PIN_LENGTH:
             raise PinError(f"PINs must be {MAX_PIN_LENGTH} digits long")
 
@@ -312,25 +384,48 @@ class System:
 
         latest_pins[label] = pin
 
-        await self._send_updated_pins(latest_pins)
+        await self._set_updated_pins(latest_pins)
 
-    async def update(self, refresh_location: bool = True, cached: bool = True) -> None:
-        """Update to the latest data (including entities)."""
-        tasks: Dict[str, Coroutine] = {
-            "entities": self._update_entities(cached),
-            "settings": self._update_settings(cached),
-        }
-        if refresh_location:
-            tasks["location"] = self._update_location_info()
+    async def update(
+        self,
+        *,
+        include_system: bool = True,
+        include_settings: bool = True,
+        include_entities: bool = True,
+        cached: bool = True,
+    ) -> None:
+        """Get the latest system data.
+
+        The ``cached`` parameter determines whether the SimpliSafe Cloud uses the last
+        known values retrieved from the base station (``True``) or retrieves new data.
+
+        :param include_system: Whether system state/properties should be updated
+        :type include_system: ``bool``
+        :param include_settings: Whether system settings (like PINs) should be updated
+        :type include_settings: ``bool``
+        :param include_entities: Whether sensors/locks/etc. should be updated
+        :type include_entities: ``bool``
+        :param cached: Whether to used cached data.
+        :type cached: ``bool``
+        """
+        tasks: Dict[str, Coroutine] = {}
+        if include_system:
+            tasks["system"] = self._get_system_info()
+        if include_settings:
+            tasks["settings"] = self._get_settings(cached)
+        if include_entities:
+            tasks["entity"] = self._get_entities(cached)
 
         results: List[Any] = await asyncio.gather(
             *tasks.values(), return_exceptions=True
         )
 
         operation: str
-        result: Any
+        result: dict
         for operation, result in zip(tasks, results):
             if isinstance(result, InvalidCredentialsError):
                 raise result
             if isinstance(result, SimplipyError):
-                _LOGGER.error("Error while retrieving %s: %s", operation, result)
+                _LOGGER.error(
+                    "Error while getting latest %s values: %s", operation, result
+                )
